function V = sVolume(sM)
% sVolume - calculates volume of an object from the spline knots in 
%		spherical coordinate system
%	V = sVolume(sM)
%	sM - spherical system spline knots
%	V  - volume
%
% see also: sFit, sFitCart

[m,n] = size(sValueM(sM));
F = sExtend(sM, [0 1], [0 0]);
F = conv2( F, 1/4*[1 1; 1 1], 'valid');

F = 4/3*pi/m*sin(pi/(2*(n-1))) * ...
	(F.^3) .* ( ones(m,1)*sin( ((1:n-1)-0.5)*pi/(n-1) ) ); 

V = sum(sum( F ));

return;


